@@ -36,9 +36,15 @@ void errorcall (SEXP call, char *format, ...);
 /* global variable */
 int hdf5_global_verbosity;
 
+#if ((H5_VERS_MAJOR > 1) || (H5_VERS_MAJOR == 1 && H5_VERS_MINOR >= 4))
+#define count_size_t hsize_t
+#else
+#define count_size_t size_t
+#endif
+
 static herr_t
 ref_string (hid_t sid, hid_t did, H5T_cdata_t *cdata,
-	    hsize_t count, size_t stride, size_t bkg_stride,
+	    count_size_t count, size_t stride, size_t bkg_stride,
 	    void *buf, void *bkg,
 	    hid_t dset_xfer_plid)
 {
@@ -64,7 +70,7 @@ ref_string (hid_t sid, hid_t did, H5T_cdata_t *cdata,
 
 static herr_t
 string_ref (hid_t sid, hid_t did, H5T_cdata_t *cdata,
-	    hsize_t count, size_t stride, size_t bkg_stride,
+	    count_size_t count, size_t stride, size_t bkg_stride,
 	    void *buf, void *bkg,
 	    hid_t dset_xfer_plid)
 {
